==> jc-1.4.0.tar.gz: gnu/java/rmi/server/RMIObjectOutputStream.h <==
// public class gnu.java.rmi.server.RMIObjectOutputStream

// class file dependencies
// @dep_class e5e2d45597aa8e22 gnu_java_rmi_server_RMIObjectOutputStream
// @dep_class adac05c7137ad26e java_io_ObjectOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_io_ObjectOutputStream

#include "java/io/ObjectOutputStream.h"

#ifndef _JC_gnu_java_rmi_server_RMIObjectOutputStream_H_
#define _JC_gnu_java_rmi_server_RMIObjectOutputStream_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$sub_refs	_jc_gnu_java_rmi_server_RMIObjectOutputStream$sub_refs;
typedef struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$sub_nonrefs	_jc_gnu_java_rmi_server_RMIObjectOutputStream$sub_nonrefs;
typedef struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$refs	_jc_gnu_java_rmi_server_RMIObjectOutputStream$refs;
typedef struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$nonrefs	_jc_gnu_java_rmi_server_RMIObjectOutputStream$nonrefs;
typedef struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$object	_jc_gnu_java_rmi_server_RMIObjectOutputStream$object;

typedef const struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$vmethods	_jc_gnu_java_rmi_server_RMIObjectOutputStream$vmethods;
typedef const struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$vtable	_jc_gnu_java_rmi_server_RMIObjectOutputStream$vtable;
typedef const struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$vtype	_jc_gnu_java_rmi_server_RMIObjectOutputStream$vtype;

// Constructors
extern void _jc_gnu_java_rmi_server_RMIObjectOutputStream$method$_init$8b48f276bbc2c828(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$object *, struct _jc_java_io_OutputStream$object *);

// Virtual methods
extern void _jc_gnu_java_rmi_server_RMIObjectOutputStream$method$annotateClass$c19f9fc18b21d777(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$object *, struct _jc_java_lang_Class$object *);
extern void _jc_gnu_java_rmi_server_RMIObjectOutputStream$method$annotateProxyClass$5025b6416b7a0ae9(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$object *, struct _jc_java_lang_Class$object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_java_rmi_server_RMIObjectOutputStream$method$replaceObject$583f65eb6fc52a9a(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$object *, struct _jc_java_lang_Object$object *);
extern void _jc_gnu_java_rmi_server_RMIObjectOutputStream$method$setAnnotation$95da01025bf29727(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$object *, struct _jc_java_lang_String$object *);
extern void _jc_gnu_java_rmi_server_RMIObjectOutputStream$method$writeValue$e5eede3b53784ac3(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Class$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_rmi_server_RMIObjectOutputStream$method_info$annotateClass$c19f9fc18b21d777;
extern _jc_method _jc_gnu_java_rmi_server_RMIObjectOutputStream$method_info$annotateProxyClass$5025b6416b7a0ae9;
extern _jc_method _jc_gnu_java_rmi_server_RMIObjectOutputStream$method_info$replaceObject$583f65eb6fc52a9a;
extern _jc_method _jc_gnu_java_rmi_server_RMIObjectOutputStream$method_info$setAnnotation$95da01025bf29727;
extern _jc_method _jc_gnu_java_rmi_server_RMIObjectOutputStream$method_info$writeValue$e5eede3b53784ac3;

// Virtual methods structure
struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$vmethods {
	void	(*annotateClass$c19f9fc18b21d777)(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$object *, struct _jc_java_lang_Class$object *);
	void	(*annotateProxyClass$5025b6416b7a0ae9)(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$object *, struct _jc_java_lang_Class$object *);
	struct _jc_java_lang_Object$object	*(*replaceObject$583f65eb6fc52a9a)(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$object *, struct _jc_java_lang_Object$object *);
	void	(*setAnnotation$95da01025bf29727)(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$object *, struct _jc_java_lang_String$object *);
	void	(*writeValue$e5eede3b53784ac3)(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Class$object *);
};

// Vtable
struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_ObjectOutputStream$vmethods	java_io_ObjectOutputStream;
	_jc_gnu_java_rmi_server_RMIObjectOutputStream$vmethods	gnu_java_rmi_server_RMIObjectOutputStream;
};

// Vtype
struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_rmi_server_RMIObjectOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$refs {
    _jc_gnu_java_rmi_server_RMIObjectOutputStream$sub_refs	gnu_java_rmi_server_RMIObjectOutputStream;
    _jc_java_io_ObjectOutputStream$sub_refs	java_io_ObjectOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_ObjectOutputStream$sub_nonrefs	java_io_ObjectOutputStream;
    _jc_gnu_java_rmi_server_RMIObjectOutputStream$sub_nonrefs	gnu_java_rmi_server_RMIObjectOutputStream;
};

// Object instance structure
struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$object {
	_jc_gnu_java_rmi_server_RMIObjectOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_rmi_server_RMIObjectOutputStream$vtype	*vtype;
	_jc_gnu_java_rmi_server_RMIObjectOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_rmi_server_RMIObjectOutputStream$vtype _jc_gnu_java_rmi_server_RMIObjectOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_rmi_server_RMIObjectOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_rmi_server_RMIObjectOutputStream$class_object;

#endif	/* _JC_gnu_java_rmi_server_RMIObjectOutputStream_H_ */

==> jc-1.4.5.tar.gz: gnu/java/rmi/server/RMIObjectOutputStream.h <==
// public class gnu.java.rmi.server.RMIObjectOutputStream

// class file dependencies
// @dep_class e5e2d45597aa8e22 gnu_java_rmi_server_RMIObjectOutputStream
// @dep_class adac05c7137ad26e java_io_ObjectOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_io_ObjectOutputStream

#include "java/io/ObjectOutputStream.h"

#ifndef _JC_gnu_java_rmi_server_RMIObjectOutputStream_H_
#define _JC_gnu_java_rmi_server_RMIObjectOutputStream_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$sub_refs	_jc_gnu_java_rmi_server_RMIObjectOutputStream$sub_refs;
typedef struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$sub_nonrefs	_jc_gnu_java_rmi_server_RMIObjectOutputStream$sub_nonrefs;
typedef struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$refs	_jc_gnu_java_rmi_server_RMIObjectOutputStream$refs;
typedef struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$nonrefs	_jc_gnu_java_rmi_server_RMIObjectOutputStream$nonrefs;
typedef struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$object	_jc_gnu_java_rmi_server_RMIObjectOutputStream$object;

typedef const struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$vmethods	_jc_gnu_java_rmi_server_RMIObjectOutputStream$vmethods;
typedef const struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$vtable	_jc_gnu_java_rmi_server_RMIObjectOutputStream$vtable;
typedef const struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$vtype	_jc_gnu_java_rmi_server_RMIObjectOutputStream$vtype;

// Constructors
extern void _jc_gnu_java_rmi_server_RMIObjectOutputStream$method$_init$8b48f276bbc2c828(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$object *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_rmi_server_RMIObjectOutputStream$method$annotateClass$c19f9fc18b21d777(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_rmi_server_RMIObjectOutputStream$method$annotateProxyClass$5025b6416b7a0ae9(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_java_rmi_server_RMIObjectOutputStream$method$replaceObject$583f65eb6fc52a9a(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_rmi_server_RMIObjectOutputStream$method$setAnnotation$95da01025bf29727(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_rmi_server_RMIObjectOutputStream$method$writeValue$e5eede3b53784ac3(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_rmi_server_RMIObjectOutputStream$method_info$annotateClass$c19f9fc18b21d777;
extern _jc_method _jc_gnu_java_rmi_server_RMIObjectOutputStream$method_info$annotateProxyClass$5025b6416b7a0ae9;
extern _jc_method _jc_gnu_java_rmi_server_RMIObjectOutputStream$method_info$replaceObject$583f65eb6fc52a9a;
extern _jc_method _jc_gnu_java_rmi_server_RMIObjectOutputStream$method_info$setAnnotation$95da01025bf29727;
extern _jc_method _jc_gnu_java_rmi_server_RMIObjectOutputStream$method_info$writeValue$e5eede3b53784ac3;

// Virtual methods structure
struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$vmethods {
	void	(*annotateClass$c19f9fc18b21d777)(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
	void	(*annotateProxyClass$5025b6416b7a0ae9)(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*replaceObject$583f65eb6fc52a9a)(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	void	(*setAnnotation$95da01025bf29727)(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*writeValue$e5eede3b53784ac3)(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_ObjectOutputStream$vmethods	java_io_ObjectOutputStream;
	_jc_gnu_java_rmi_server_RMIObjectOutputStream$vmethods	gnu_java_rmi_server_RMIObjectOutputStream;
};

// Vtype
struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_rmi_server_RMIObjectOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$refs {
    _jc_gnu_java_rmi_server_RMIObjectOutputStream$sub_refs	gnu_java_rmi_server_RMIObjectOutputStream;
    _jc_java_io_ObjectOutputStream$sub_refs	java_io_ObjectOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_ObjectOutputStream$sub_nonrefs	java_io_ObjectOutputStream;
    _jc_gnu_java_rmi_server_RMIObjectOutputStream$sub_nonrefs	gnu_java_rmi_server_RMIObjectOutputStream;
};

// Object instance structure
struct _jc_gnu_java_rmi_server_RMIObjectOutputStream$object {
	_jc_gnu_java_rmi_server_RMIObjectOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_rmi_server_RMIObjectOutputStream$vtype	*vtype;
	_jc_gnu_java_rmi_server_RMIObjectOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_rmi_server_RMIObjectOutputStream$vtype _jc_gnu_java_rmi_server_RMIObjectOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_rmi_server_RMIObjectOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_rmi_server_RMIObjectOutputStream$class_object;

#endif	/* _JC_gnu_java_rmi_server_RMIObjectOutputStream_H_ */
